# yamlfix

[![Actions Status](https://github.com/lyz-code/yamlfix/workflows/Tests/badge.svg)](https://github.com/lyz-code/yamlfix/actions)
[![Actions Status](https://github.com/lyz-code/yamlfix/workflows/Build/badge.svg)](https://github.com/lyz-code/yamlfix/actions)
[![Coverage Status](https://coveralls.io/repos/github/lyz-code/yamlfix/badge.svg?branch=master)](https://coveralls.io/github/lyz-code/yamlfix?branch=master)

A simple opinionated yaml formatter that keeps your comments!

## Help

See [documentation](https://lyz-code.github.io/yamlfix) for more details.

## Installing

```bash
pip install yamlfix
```

## Contributing

For guidance on setting up a development environment, and how to make
a contribution to *yamlfix*, see [Contributing to
yamlfix](https://lyz-code.github.io/yamlfix/contributing).

## License

GPLv3
